# TraneTech 高效机房在线优化平台 - 后端

## 项目介绍

TraneTech 高效机房在线优化平台是一个专为数据中心和机房设计的能源策略优化系统，旨在提高能源利用效率、降低运营成本，并实现智能化管理。该平台通过收集和分析机房设备的运行数据，结合先进的算法模型，为用户提供最优化的能源使用策略，实现节能减排的目标。

### 主要功能

- 机房设备实时监控与数据采集
- 能源消耗分析与可视化
- 智能化能源策略优化与推荐
- 设备运行状态预测与维护提醒
- 多维度报表生成与数据导出

## 技术架构

该项目采用现代化的技术栈，采用微服务架构设计：

- **开发框架**：Spring Boot 2.4.5
- **数据持久层**：Spring Data JPA、MyBatis-Plus
- **数据库**：MySQL 8.0
- **消息队列**：MQTT、RabbitMQ
- **API文档**：Swagger 2.7.0
- **数据分片**：ShardingSphere JDBC
- **Excel处理**：Apache POI
- **表达式引擎**：Aviator
- **日志管理**：Log4j2
- **远程调用**：OpenFeign

## 系统要求

- JDK 8
- Maven 3.6+
- MySQL 8.0+
- Docker & Docker Compose (可选，用于容器化部署)

## 安装与部署

### 方式一：直接运行

1. 克隆项目代码
   ```bash
   git clone https://github.com/yourusername/trane-tech-energy-strategy-optimization-platform-backend-dev.git
   cd trane-tech-energy-strategy-optimization-platform-backend-dev
   ```

2. 配置数据库
   - 确保MySQL服务已启动
   - 根据需要修改 `src/main/resources/application.yml` 和相应环境的配置文件
   - 默认连接配置在 `application-dev.yml`、`application-test.yml` 等文件中

3. 编译打包
   ```bash
   mvn clean package -DskipTests
   ```

4. 运行应用
   ```bash
   java -jar target/application.project-1.0.jar --spring.profiles.active=dev
   ```
   
### 方式二：Docker 部署

1. 构建Docker镜像
   ```bash
   docker build -t trane-tech-backend:latest .
   ```

2. 使用Docker Compose启动应用
   ```bash
   docker-compose up -d mysql    # 先启动数据库
   docker-compose up -d          # 启动所有服务
   ```

## 开发指南

### 项目结构

```
src/main/java/
├── common/                # 公共组件
├── org/
│   ├── example/           # 基础功能模块
│   │   ├── Main.java      # 应用程序入口
│   │   ├── controller/    # 控制器
│   │   ├── service/       # 服务层
│   │   ├── mapper/        # MyBatis映射器
│   │   ├── entity/        # 实体类
│   │   └── utils/         # 工具类
│   ├── trane/
│   │   └── project/       # 项目核心功能
│   │       ├── controller/
│   │       ├── service/
│   │       ├── mapper/
│   │       ├── entity/
│   │       ├── dto/       # 数据传输对象
│   │       └── vo/        # 值对象
│   └── module/            # 其他功能模块
└── resources/
    ├── application.yml    # 主配置文件
    ├── application-*.yml  # 各环境配置文件
    └── mapper/            # MyBatis XML映射文件
```

### 开发环境配置

1. 推荐使用IntelliJ IDEA作为开发环境
2. 导入项目为Maven项目
3. 配置JDK 8
4. 安装Lombok插件以支持注解处理

### 代码贡献流程

1. Fork本仓库
2. 创建功能分支 (`git checkout -b feature/your-feature`)
3. 提交代码 (`git commit -m 'Add some feature'`)
4. 推送到远程分支 (`git push origin feature/your-feature`)
5. 创建Pull Request

## API文档

项目集成了Swagger作为API文档工具，启动应用后可通过以下地址访问：

```
http://localhost:8082/swagger-ui.html
```

## 许可证

[添加项目许可证信息]

## 联系方式

[添加项目维护者联系方式]
